@@ -4,11 +4,10 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef CLIPBOARDLISTENER_H
-#define CLIPBOARDLISTENER_H
+#pragma once
 
-#include <QObject>
 #include <QClipboard>
+#include <QObject>
 
 #ifdef Q_OS_MAC
 #include <QTimer>
@@ -24,24 +23,32 @@ class ClipboardListener : public QObject
 {
     Q_OBJECT
 
+public:
+    enum ClipboardContentType {
+        ClipboardContentTypeUnknown = 0,
+        ClipboardContentTypePassword = 1,
+    };
+
 protected:
     ClipboardListener();
-    void refreshContent(const QString &content);
+    void refreshContent(const QString &content, ClipboardContentType contentType);
     QString m_currentContent;
+    ClipboardContentType m_currentContentType;
 
 private:
     qint64 m_updateTimestamp = 0;
 
 public:
-    static ClipboardListener* instance();
+    static ClipboardListener *instance();
 
-    void setText(const QString& content);
+    void setText(const QString &content);
 
     QString currentContent();
+    ClipboardContentType currentContentType();
     qint64 updateTimestamp();
 
 Q_SIGNALS:
-    void clipboardChanged(const QString& content);
+    void clipboardChanged(const QString &content, ClipboardContentType contentType);
 
 private:
     void updateClipboard(QClipboard::Mode mode);
@@ -51,5 +58,3 @@ private:
 #endif
     KSystemClipboard *clipboard;
 };
-
-#endif
